
from django.apps import AppConfig

from .ckeditor_config import DEFAULT_CONFIG

default_app_config = 'leonardo_ckeditor.Config'

LEONARDO_APPS = [
    'leonardo_ckeditor',
    'ckeditor',
    'ckeditor_uploader'
]

LEONARDO_CONFIG = {
    'CKEDITOR_UPLOAD_PATH': ('uploads/', ('CKEditor upload directory')),
    'CKEDITOR_CONFIGS': ({'default': DEFAULT_CONFIG}, 'ckeditor config')
}
LEONARDO_OPTGROUP = 'CKEditor'

LEONARDO_JS_FILES = [
    "leonardo_ckeditor/js/ckeditor-modal-init.js",
]
LEONARDO_CSS_FILES = [
    'ckeditor/ckeditor/skins/moono/editor.css'
]
LEONARDO_PUBLIC = True

LEONARDO_URLS_CONF = 'ckeditor_uploader.urls'


class Config(AppConfig):
    name = 'leonardo_ckeditor'
    verbose_name = "leonardo-ckeditor"

    def ready(self):
        from ckeditor.widgets import CKEditorWidget
        from leonardo.module.web.widget.htmltext import models
        models.HtmlTextWidget.widgets['text'] = CKEditorWidget()





from ckeditor.widgets import DEFAULT_CONFIG

DEFAULT_CONFIG.update({'allowedContent': True})
DEFAULT_CONFIG.update({'height': 350})

DEFAULT_CONFIG.update({'toolbar_Full': [
    ["Cut", "Copy", "Paste", "PasteText",
     "PasteFromWord", "-", "Undo", "Redo"],
    ["Find", "Replace", "-", "SelectAll", "-", "SpellChecker", "Scayt"],
    ["Form", "Checkbox", "Radio", "TextField", "Textarea",
        "Select", "Button", "ImageButton", "HiddenField"],
    ["Bold", "Italic", "Underline", "Strike",
        "Subscript", "Superscript", "-", "RemoveFormat"],
    ["NumberedList", "BulletedList", "-", "Outdent",
     "Indent", "-", "Blockquote", "CreateDiv",
        "-", "JustifyLeft", "JustifyCenter", "JustifyRight",
        "JustifyBlock", "-", "BidiLtr", "BidiRtl"],
    ["Link", "Unlink", "Anchor"],
    ["Image", "Flash", "Table", "HorizontalRule",
        "Smiley", "SpecialChar", "PageBreak", "Iframe"],
    ["Styles", "Format", "Font", "FontSize"],
    ["TextColor", "BGColor"],
    ["Maximize", "ShowBlocks"],
    ["Source"]]})
